@@ -2,26 +2,11 @@ import argparse
 import signal
 
 from . import __version__
-from . import auth
+from . import configure
 from . import publish
 from . import subscribe
 from . import version
-
-
-def append_subparser(subparser, cmd, func):
-    assert func.__doc__, "empty docstring: {}".format(func)
-    help_ = func.__doc__.split("\n")[0].lower().strip(".")
-    desc = func.__doc__.strip()
-
-    parser = subparser.add_parser(
-        cmd,
-        formatter_class=argparse.RawDescriptionHelpFormatter,
-        help=help_,
-        description=desc,
-    )
-
-    parser.set_defaults(func=func)
-    return parser
+from .utils import cli as cli_utils
 
 
 def set_up_cli():
@@ -32,26 +17,31 @@ def set_up_cli():
         arguments added for all commands.
 
     """
-    parser = argparse.ArgumentParser(prog="hop")
+    parser = argparse.ArgumentParser(prog="hop", formatter_class=cli_utils.SubcommandHelpFormatter)
     parser.add_argument(
         "--version", action="version", version=f"%(prog)s version {__version__}",
     )
 
     # set up subparser
-    subparser = parser.add_subparsers(title="Commands", metavar="<command>", dest="cmd")
+    subparser = parser.add_subparsers(title="commands", metavar="<command>", dest="cmd")
     subparser.required = True
 
     # register commands
-    p = append_subparser(subparser, "auth", auth._main)
-    auth._add_parser_args(p)
+    p = cli_utils.append_subparser(
+        subparser,
+        "configure",
+        configure._main,
+        formatter_class=cli_utils.SubcommandHelpFormatter
+    )
+    configure._add_parser_args(p)
 
-    p = append_subparser(subparser, "publish", publish._main)
+    p = cli_utils.append_subparser(subparser, "publish", publish._main)
     publish._add_parser_args(p)
 
-    p = append_subparser(subparser, "subscribe", subscribe._main)
+    p = cli_utils.append_subparser(subparser, "subscribe", subscribe._main)
     subscribe._add_parser_args(p)
 
-    p = append_subparser(subparser, "version", version._main)
+    p = cli_utils.append_subparser(subparser, "version", version._main)
 
     return parser
 
