@@ -1,3 +1,5 @@
+import sys
+
 from . import cli
 from . import io
 
@@ -5,7 +7,7 @@ from . import io
 def _add_parser_args(parser):
     cli.add_client_opts(parser)
     parser.add_argument(
-        "message", metavar="MESSAGE", nargs="+", help="One or more messages to publish.",
+        "message", metavar="MESSAGE", nargs="*", help="Messages to publish.",
     )
     parser.add_argument(
         "-f",
@@ -17,7 +19,7 @@ def _add_parser_args(parser):
 
 
 def _main(args):
-    """Parse and publish messages.
+    """Publish messages.
 
     """
     loader = io.Deserializer[args.format]
@@ -27,3 +29,14 @@ def _main(args):
         for message_file in args.message:
             message = loader.load_file(message_file)
             s.write(message)
+
+        # check if stdin is connected to TTY device
+        if not sys.stdin.isatty():
+            messages = sys.stdin.read().splitlines()
+
+            if messages:
+                assert args.format == io.Deserializer.BLOB.name, \
+                    "piping/redirection only allowed for BLOB formats"
+
+                for message in messages:
+                    s.write(loader.load(message))
